## Version 0.9.3 (2022/01/08)


### Pull Requests Merged

#### Bugs fixed

* [PR 27](https://github.com/pytroll/pytroll-aapp-runner/pull/27) - Correct message level duplicate scene
* [PR 26](https://github.com/pytroll/pytroll-aapp-runner/pull/26) - Bugfix mhs calibration

#### Features added

* [PR 28](https://github.com/pytroll/pytroll-aapp-runner/pull/28) - Update readme file and add changelog and releasing guide
* [PR 26](https://github.com/pytroll/pytroll-aapp-runner/pull/26) - Bugfix mhs calibration

In this release 4 pull requests were closed.


## Version 0.9.2


### Pull Requests Merged

#### Bugs fixed

* [PR 21](https://github.com/pytroll/pytroll-aapp-runner/pull/21) - Bugfix: Nameservers list should be None on default

#### Features added

* [PR 19](https://github.com/pytroll/pytroll-aapp-runner/pull/19) - Refactor aapp runner
* [PR 18](https://github.com/pytroll/pytroll-aapp-runner/pull/18) - Add support for log config setup
* [PR 17](https://github.com/pytroll/pytroll-aapp-runner/pull/17) - Adding unittests and minor refactoring
* [PR 16](https://github.com/pytroll/pytroll-aapp-runner/pull/16) - Use setuptools scm versioning

In this release 5 pull requests were closed.


## Version 0.9.1

(There were no annotated tags before this one. Thus, no loghub history.)
